==> qmmp_2.2.3.orig.tar.bz2: qmmp-2.2.3/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="33"/>
        <source>Show playlist manipulation commands</source>
        <translation>Montrer les commandes de manipulation de liste</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="34"/>
        <source>List all available playlists</source>
        <translation>Montrer toutes les listes disponibles</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="35"/>
        <source>Show playlist content</source>
        <translation>Montrer le contenu de la liste</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="36"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation>Lire le morceau &lt;track&gt; dans la liste &lt;id&gt;</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="37"/>
        <source>Clear playlist</source>
        <translation>Vider la liste</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="38"/>
        <source>Activate next playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="39"/>
        <source>Activate previous playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="40"/>
        <source>Toggle playlist repeat</source>
        <translation>Activer/Désactiver la répétition de liste</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="41"/>
        <source>Toggle playlist shuffle</source>
        <translation>Activer/Désactiver la lecture aléatoire</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="42"/>
        <source>Show playlist options</source>
        <translation>Montrer les options de liste</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="112"/>
        <location filename="../playlistoption.cpp" line="132"/>
        <location filename="../playlistoption.cpp" line="171"/>
        <source>Invalid playlist ID</source>
        <translation>Identifiant de liste invalide</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="126"/>
        <source>Invalid number of arguments</source>
        <translation>Nombre d&apos;arguments invalide</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="136"/>
        <source>Invalid track ID</source>
        <translation>Identifiant de morceau invalide</translation>
    </message>
</context>
</TS>

==> qmmp_2.3.0.orig.tar.bz2: qmmp-2.3.0/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="33"/>
        <source>Show playlist manipulation commands</source>
        <translation>Montrer les commandes de manipulation de liste</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="34"/>
        <source>List all available playlists</source>
        <translation>Montrer toutes les listes disponibles</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="35"/>
        <source>Show playlist content</source>
        <translation>Montrer le contenu de la liste</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="36"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation>Lire le morceau &lt;track&gt; dans la liste &lt;id&gt;</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="37"/>
        <source>Clear playlist</source>
        <translation>Vider la liste</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="38"/>
        <source>Activate next playlist</source>
        <translation>Activer la liste de lecture suivante</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="39"/>
        <source>Activate previous playlist</source>
        <translation>Activer la liste de lecture précédente</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="40"/>
        <source>Toggle playlist repeat</source>
        <translation>Activer/Désactiver la répétition de liste</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="41"/>
        <source>Toggle playlist shuffle</source>
        <translation>Activer/Désactiver la lecture aléatoire</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="42"/>
        <source>Show playlist options</source>
        <translation>Montrer les options de liste</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="112"/>
        <location filename="../playlistoption.cpp" line="134"/>
        <location filename="../playlistoption.cpp" line="173"/>
        <source>Invalid playlist ID</source>
        <translation>Identifiant de liste invalide</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="128"/>
        <source>Invalid number of arguments</source>
        <translation>Nombre d&apos;arguments invalide</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="138"/>
        <source>Invalid track ID</source>
        <translation>Identifiant de morceau invalide</translation>
    </message>
</context>
</TS>
